==> ejc-zhengyuan-impl-3.0.0-20241227.024427-13-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanPapersReportsVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 论文、报告
 * 
 * @author generator
 * 
 */
public class KeyanPapersReportsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long unitId; // 所属单位id
    private String unitName; // 所属单位名称
    private String papersName; // 论文名称
    private String publicationCategory; // 所发表刊物类别
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date publicationTime; // 发表时间
    private String countryInOut; // 国内/外
    private String publishJournal; // 发表期刊（会刊）
    private String issn; // ISSN
    private String cn; // CN
    private String period; // 卷（期）
    private String page; // 页
    private String searchCategory; // 检索类别
    private String influenceFactors; // 影响因子
    private String author; // 作者
    private String authorRank; // 本单位作者位次
    private String firstAuthorAffiliation; // 第一作者单位
    private String communicationAuthorAffiliation; // 通讯作者单位
    private String remarks; // 备注

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getUnitId() {
        return unitId;
    }

    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getPapersName() {
        return papersName;
    }

    public void setPapersName(String papersName) {
        this.papersName = papersName;
    }
    public String getPublicationCategory() {
        return publicationCategory;
    }

    public void setPublicationCategory(String publicationCategory) {
        this.publicationCategory = publicationCategory;
    }
    public Date getPublicationTime() {
        return publicationTime;
    }

    public void setPublicationTime(Date publicationTime) {
        this.publicationTime = publicationTime;
    }
    public String getCountryInOut() {
        return countryInOut;
    }

    public void setCountryInOut(String countryInOut) {
        this.countryInOut = countryInOut;
    }
    public String getPublishJournal() {
        return publishJournal;
    }

    public void setPublishJournal(String publishJournal) {
        this.publishJournal = publishJournal;
    }
    public String getIssn() {
        return issn;
    }

    public void setIssn(String issn) {
        this.issn = issn;
    }
    public String getCn() {
        return cn;
    }

    public void setCn(String cn) {
        this.cn = cn;
    }
    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }
    public String getPage() {
        return page;
    }

    public void setPage(String page) {
        this.page = page;
    }
    public String getSearchCategory() {
        return searchCategory;
    }

    public void setSearchCategory(String searchCategory) {
        this.searchCategory = searchCategory;
    }
    public String getInfluenceFactors() {
        return influenceFactors;
    }

    public void setInfluenceFactors(String influenceFactors) {
        this.influenceFactors = influenceFactors;
    }
    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }
    public String getAuthorRank() {
        return authorRank;
    }

    public void setAuthorRank(String authorRank) {
        this.authorRank = authorRank;
    }
    public String getFirstAuthorAffiliation() {
        return firstAuthorAffiliation;
    }

    public void setFirstAuthorAffiliation(String firstAuthorAffiliation) {
        this.firstAuthorAffiliation = firstAuthorAffiliation;
    }
    public String getCommunicationAuthorAffiliation() {
        return communicationAuthorAffiliation;
    }

    public void setCommunicationAuthorAffiliation(String communicationAuthorAffiliation) {
        this.communicationAuthorAffiliation = communicationAuthorAffiliation;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-zhengyuan-impl-3.0.0-20251202.044802-53-sources.jar: com/ejianc/business/sq/keyan/vo/KeyanPapersReportsVO.java <==
package com.ejianc.business.sq.keyan.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.Date;


/**
 * 论文、报告
 * 
 * @author generator
 * 
 */
public class KeyanPapersReportsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Integer billState; // 单据审批状态
    private String billCode; // 单据编码
    private Long unitId; // 所属单位id
    private String unitName; // 所属单位名称
    private String papersName; // 论文名称
    private String publicationCategory; // 所发表刊物类别
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date publicationTime; // 发表时间
    private String countryInOut; // 国内/外
    private String publishJournal; // 发表期刊（会刊）
    private String issn; // ISSN
    private String cn; // CN
    private String period; // 卷（期）
    private String page; // 页
    private String searchCategory; // 检索类别
    private String influenceFactors; // 影响因子
    private String author; // 作者
    private String authorRank; // 本单位作者位次
    private String firstAuthorAffiliation; // 第一作者单位
    private String communicationAuthorAffiliation; // 通讯作者单位
    private String remarks; // 备注

    private String errorMsg; // 导入错误信息

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getUnitId() {
        return unitId;
    }

    @ReferDeserialTransfer
    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getPapersName() {
        return papersName;
    }

    public void setPapersName(String papersName) {
        this.papersName = papersName;
    }
    public String getPublicationCategory() {
        return publicationCategory;
    }

    public void setPublicationCategory(String publicationCategory) {
        this.publicationCategory = publicationCategory;
    }
    public Date getPublicationTime() {
        return publicationTime;
    }

    public void setPublicationTime(Date publicationTime) {
        this.publicationTime = publicationTime;
    }
    public String getCountryInOut() {
        return countryInOut;
    }

    public void setCountryInOut(String countryInOut) {
        this.countryInOut = countryInOut;
    }
    public String getPublishJournal() {
        return publishJournal;
    }

    public void setPublishJournal(String publishJournal) {
        this.publishJournal = publishJournal;
    }
    public String getIssn() {
        return issn;
    }

    public void setIssn(String issn) {
        this.issn = issn;
    }
    public String getCn() {
        return cn;
    }

    public void setCn(String cn) {
        this.cn = cn;
    }
    public String getPeriod() {
        return period;
    }

    public void setPeriod(String period) {
        this.period = period;
    }
    public String getPage() {
        return page;
    }

    public void setPage(String page) {
        this.page = page;
    }
    public String getSearchCategory() {
        return searchCategory;
    }

    public void setSearchCategory(String searchCategory) {
        this.searchCategory = searchCategory;
    }
    public String getInfluenceFactors() {
        return influenceFactors;
    }

    public void setInfluenceFactors(String influenceFactors) {
        this.influenceFactors = influenceFactors;
    }
    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }
    public String getAuthorRank() {
        return authorRank;
    }

    public void setAuthorRank(String authorRank) {
        this.authorRank = authorRank;
    }
    public String getFirstAuthorAffiliation() {
        return firstAuthorAffiliation;
    }

    public void setFirstAuthorAffiliation(String firstAuthorAffiliation) {
        this.firstAuthorAffiliation = firstAuthorAffiliation;
    }
    public String getCommunicationAuthorAffiliation() {
        return communicationAuthorAffiliation;
    }

    public void setCommunicationAuthorAffiliation(String communicationAuthorAffiliation) {
        this.communicationAuthorAffiliation = communicationAuthorAffiliation;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
    
}
